.. Copyright 2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Package reahl.web.bootstrap.files
---------------------------------

.. automodule:: reahl.web.bootstrap.files

.. sidebar:: Examples

   - tutorial.fileuploadbootstrap

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>


FileInputButton
"""""""""""""""

.. autoclass:: FileInputButton
   :members:


FileInput
"""""""""

.. autoclass:: FileInput
   :members:


FileUploadInput
"""""""""""""""

.. autoclass:: FileUploadInput
   :members:
